The OOGillespie Module
======================

This module provides a class that allows to simulate a stochastic process with discrete, Poissonian events with the Gillespie algorithm.

In contrast to other implementations it embraces object-oriented programming, which has its advantages and disadvantages:

* It is easy to use if you are already familiar with object-oriented programming in Python.

* It may be good for you if its way of doing things comes to you naturally.

* It is very flexible.

* It is not fast.

A Simple Example: Birth and Death
=================================

.. automodule:: birth_death

An Advanced Example: Rock, Paper, Scissors
==========================================

.. automodule:: rock_paper_scissors

Command reference
=================

.. automodule:: _oogillespie
.. autoclass:: Event
    :members:

.. autoclass:: Gillespie
    :members:




